( cd usr/lib ; rm -rf libaprutil-1.so.0 )
( cd usr/lib ; ln -sf libaprutil-1.so.0.3.12 libaprutil-1.so.0 )
( cd usr/lib ; rm -rf libaprutil-1.so )
( cd usr/lib ; ln -sf libaprutil-1.so.0.3.12 libaprutil-1.so )
